@@ -309,4 +309,10 @@ extern PGDLLEXPORT Datum orafce_textregexreplace_extended(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_textregexreplace_extended_no_n(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_textregexreplace_extended_no_flags(PG_FUNCTION_ARGS);
 
+/* from math.c */
+extern Datum orafce_reminder_smallint(PG_FUNCTION_ARGS);
+extern Datum orafce_reminder_int(PG_FUNCTION_ARGS);
+extern Datum orafce_reminder_bigint(PG_FUNCTION_ARGS);
+extern Datum orafce_reminder_numeric(PG_FUNCTION_ARGS);
+
 #endif
