@@ -35,25 +35,12 @@ typedef struct {
 
 PG_FUNCTION_INFO_V1(plvlex_tokens);
 
-extern int      orafce_sql_yyparse();
 extern void orafce_sql_yyerror(List **result, const char *message);
 extern void orafce_sql_scanner_init(const char *str);
 extern void orafce_sql_scanner_finish(void);
 
 static orafce_lexnode *__node;
 
-static char *__result;
-static int __len;
-
-#define CSTRING(txt) \
-	( \
-    __len = VARSIZE(txt) - VARHDRSZ, \
-    __result = palloc(__len + 1), \
-    memcpy(__result, VARDATA(txt), __len), \
-    __result[__len] = '\0', \
-    __result)
-
-
 #define COPY_TO_S(src,dest,col)	(dest->col = (src->col ? pstrdup(src->col) : NULL))
 #define COPY_TO(src,dest,col)	(dest->col = src->col)
 
@@ -197,7 +184,7 @@ plvlex_tokens(PG_FUNCTION_ARGS)
 		bool skip_spaces = PG_GETARG_BOOL(1);
 		bool qnames = PG_GETARG_BOOL(2);
 
-		orafce_sql_scanner_init(CSTRING(src));
+		orafce_sql_scanner_init(text_to_cstring(src));
 		if (orafce_sql_yyparse(&lexems) != 0)
 			orafce_sql_yyerror(NULL, "bogus input");
 
@@ -244,7 +231,6 @@ plvlex_tokens(PG_FUNCTION_ARGS)
 		MemoryContextSwitchTo (oldcontext);
 	}
 
-
 	funcctx = SRF_PERCALL_SETUP ();
 	fctx = (tokensFctx*) funcctx->user_fctx;
 
